@@ -6,6 +6,7 @@ import pandas as pd
 import pytz
 import requests
 from bs4 import BeautifulSoup
+import logging
 
 from .exceptions import NoMatchingDataError, PaginationError
 from .mappings import DOMAIN_MAPPINGS, BIDDING_ZONES, TIMEZONE_MAPPINGS, NEIGHBOURS
@@ -14,9 +15,10 @@ from .parsers import parse_prices, parse_loads, parse_generation, \
     parse_generation_per_plant, parse_installed_capacity_per_plant, \
     parse_crossborder_flows, parse_imbalance_prices, parse_unavailabilities, \
     parse_contracted_reserve
+from entsoe.exceptions import InvalidPSRTypeError, InvalidBusinessParameterError
 
 __title__ = "entsoe-py"
-__version__ = "0.2.12"
+__version__ = "0.2.13"
 __author__ = "EnergieID.be"
 __license__ = "MIT"
 
@@ -99,6 +101,7 @@ class EntsoeRawClient:
         }
         params.update(base_params)
 
+        logging.debug(f'Performing request to {URL} with params {params}')
         response = self.session.get(url=URL, params=params,
                                     proxies=self.proxies)
         try:
@@ -108,10 +111,12 @@ class EntsoeRawClient:
             text = soup.find_all('text')
             if len(text):
                 error_text = soup.find('text').text
-                if 'No matching data found' in error_text \
-                        or "is not valid for this area" in error_text \
-                        or "check you request against dependency tables" in error_text:
+                if 'No matching data found' in error_text:
                     raise NoMatchingDataError
+                elif "check you request against dependency tables" in error_text:
+                    raise InvalidBusinessParameterError
+                elif "is not valid for this area" in error_text:
+                    raise InvalidPSRTypeError
                 elif 'amount of requested data exceeds allowed limit' in error_text:
                     requested = error_text.split(' ')[-2]
                     allowed = error_text.split(' ')[-5]
@@ -187,7 +192,7 @@ class EntsoeRawClient:
         response = self.base_request(params=params, start=start, end=end)
         return response.text
 
-    def query_load_forecast(self, country_code, start, end):
+    def query_load_forecast(self, country_code, start, end, process_type = 'A01'):
         """
         Parameters
         ----------
@@ -201,14 +206,14 @@ class EntsoeRawClient:
         domain = BIDDING_ZONES[country_code]
         params = {
             'documentType': 'A65',
-            'processType': 'A01',
+            'processType': process_type,
             'outBiddingZone_Domain': domain,
             # 'out_Domain': domain
         }
         response = self.base_request(params=params, start=start, end=end)
         return response.text
 
-    def query_generation_forecast(self, country_code, start, end):
+    def query_generation_forecast(self, country_code, start, end, process_type = 'A01'):
         """
         Parameters
         ----------
@@ -223,13 +228,14 @@ class EntsoeRawClient:
         domain = BIDDING_ZONES[country_code]
         params = {
             'documentType': 'A71',
-            'processType': 'A01',
+            'processType': process_type,
             'in_Domain': domain,
         }
+
         response = self.base_request(params=params, start=start, end=end)
         return response.text
 
-    def query_wind_and_solar_forecast(self, country_code, start, end, psr_type=None, lookup_bzones=False):
+    def query_wind_and_solar_forecast(self, country_code, start, end, psr_type=None, process_type = 'A01', lookup_bzones=False):
         """
         Parameters
         ----------
@@ -252,7 +258,7 @@ class EntsoeRawClient:
 
         params = {
             'documentType': 'A69',
-            'processType': 'A01',
+            'processType': process_type,
             'in_Domain': domain,
         }
         if psr_type:
@@ -431,7 +437,7 @@ class EntsoeRawClient:
                           contract_marketagreement_type = None,
                           lookup_bzones = False):
         """
-        Generic function called by query_crossborder_flows and 
+        Generic function called by query_crossborder_flows and
         query_scheduled_exchanges.
         Parameters
         ----------
@@ -814,7 +820,7 @@ class EntsoePandasClient(EntsoeRawClient):
         return series
 
     @year_limited
-    def query_load_forecast(self, country_code, start, end) -> pd.Series:
+    def query_load_forecast(self, country_code, start, end, process_type='A01') -> pd.Series:
         """
         Parameters
         ----------
@@ -826,14 +832,14 @@ class EntsoePandasClient(EntsoeRawClient):
         pd.Series
         """
         text = super(EntsoePandasClient, self).query_load_forecast(
-            country_code=country_code, start=start, end=end)
+            country_code=country_code, start=start, end=end, process_type=process_type)
         series = parse_loads(text)
         series = series.tz_convert(TIMEZONE_MAPPINGS[country_code])
         series = series.truncate(before=start, after=end)
         return series
 
     @year_limited
-    def query_generation_forecast(self, country_code, start, end) -> pd.Series:
+    def query_generation_forecast(self, country_code, start, end, process_type='A01') -> pd.Series:
         """
         Parameters
         ----------
@@ -845,7 +851,7 @@ class EntsoePandasClient(EntsoeRawClient):
         pd.Series
         """
         text = super(EntsoePandasClient, self).query_generation_forecast(
-            country_code=country_code, start=start, end=end)
+            country_code=country_code, start=start, end=end, process_type=process_type)
         series = parse_loads(text)
         series = series.tz_convert(TIMEZONE_MAPPINGS[country_code])
         series = series.truncate(before=start, after=end)
@@ -853,7 +859,7 @@ class EntsoePandasClient(EntsoeRawClient):
 
     @year_limited
     def query_wind_and_solar_forecast(self, country_code, start, end, psr_type=None,
-                                      lookup_bzones=False):
+                                      process_type='A01', lookup_bzones=False):
         """
         Parameters
         ----------
@@ -871,7 +877,7 @@ class EntsoePandasClient(EntsoeRawClient):
         """
         text = super(EntsoePandasClient, self).query_wind_and_solar_forecast(
             country_code=country_code, start=start, end=end, psr_type=psr_type,
-            lookup_bzones=lookup_bzones)
+            process_type=process_type, lookup_bzones=lookup_bzones)
         df = parse_generation(text)
         df = df.tz_convert(TIMEZONE_MAPPINGS[country_code])
         df = df.truncate(before=start, after=end)
